@@ -274,11 +274,13 @@ def doParseMessage():
                     tmpReJsonReturn.extend(tmpJsonReturn)
                 
                 tmpContent = JsonWriter().write(tmpReJsonReturn)
+                tmpContent = tmpContent.encode("utf-8",'utf-8')
                 
                 file_object = open(ROOT_PATH+'cache/account/message.txt', 'w+')
                 file_object.writelines(tmpContent)
                 file_object.close()
                 
+                doMessageShow('You hava a new message, Click the bottom of the view. ')
                 print "hava new message!"
     
         
